@@ -5,16 +5,14 @@ class filter_data:
         ''' In multiple filter function you can filter upto ten data 10 
         only you have to pass yor value as list(respect to multiple filter)
         '''
-    def pysprk_filter(self,df,column,val,typ):
+    def pysprk_filter(self,df,column,val):
         '''
         df="Data Frame"
         Column="target column"
         val -> "string/List"
-        Type:
-            0 -> "Equal"
-            1 -> "not-Equal"
-            2 -> isnull()'''
-        if typ==0:
+        '''
+        typ=input("kindly enter \n which filter do you want to perorm\n 0 -> 'Equal'\n 1 -> 'not-Equal' \n 2 -> 'isnull' \n kindly pass your value as 1 or 2 or 3 \n")
+        if typ=="Equal":
             if type(val)==list and len(val)<=10:
                 if len(val)==2:
                     df=df.filter((col(column)==val[0])|(col(column)==val[1]))
@@ -46,7 +44,7 @@ class filter_data:
                 df=df.filter(col(column)==val)
             else:
                 pass
-        elif typ==1:
+        elif typ=="not-Equal":
             if type(val)==list and len(val)<=10:
                 if len(val)==2:
                     df=df.filter((col(column)!=val[0])|(col(column)!=val[1]))
@@ -78,7 +76,7 @@ class filter_data:
                 df=df.filter(col(column)!=val)
             else:
                 pass
-        elif typ==2:
+        elif typ=="isnull()":
             df=df.filter(col(column).isNull())
         else:
             pass
